#[repr(u8)]pub enum Comb {
OR = 0,
AND = 1,
}Variants
OR = 0
Or. OR functionality: A grouped interrupt is generated when any one of the enabled inputs is active (based on its programmed polarity).
AND = 1
And. AND functionality: An interrupt is generated when all enabled bits are active (based on their programmed polarity).
Implementations